/*
** Module   : ButtonConfig.java
** Abstract : stores button specific widget state
**
** Copyright (c) 2005-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------------------Description-----------------------------
** 001 EVL 20050714   @21692 Creation based on general concept. Necessary
**                           modification to get compiled.
** 002 SIY 20050831   @22488 Refactoring (see @@22394-22409).
** 003 EVL 20050908   @22612 Fix for setting action command for auto_go
**                           end auto_end_key events. Changing location
**                           of the string event constants.
** 004 SIY 20060209   @24480 Major refactoring.
** 005 SIY 20060215   @24596 Fixed colors.
** 006 GES 20060803   @28394 Made externalizable for better performance.
**                           Many code standard cleanups.
** 007 SIY 20061102   @30940 Minor changes caused by field encapsulation.
** 008 SIY 20100619          Switching to own implementation of character UI.
** 009 SIY 20100804          Changes in imports, some refactorings.
** 010 SIY 20101001          Added more button options.
** 011 SIY 20101122          Changes related to Button hierarchy cleanup.
**                           Minor cleanups.
** 012 SIY 20110112          Changes related to new color handling scheme.
** 013 SIY 20111101          Moved from CHUI package. Minor 
**                           cleanups/refactorings in preparation to GUI client.
** 014 SIY 20111202          Updated imports.
** 015 GES 20140627          Changed color attribute method names to match naming standards.
** 016 CA  20140926          Added shared widget configuration support, to allow GUI/ChUI
**                           concrete implementation for the same widget ID.  Refactored the
**                           widget configuration classes: all fields were made public; these
**                           classes need to be as dumb as possible, all logic related to
**                           setting/getting a certain field should be at the widget or at the
**                           caller. Refs #2254
** 017 EVL 20150115          Adding constants to differentiate images to be loaded.
*/

package com.goldencode.p2j.ui;

import java.io.*;

/**
 * Stores button-specific state.
 */
public class ButtonConfig
extends ControlConfig
{
   /** Image widget uses this. */   
   public static final int IMAGE_IMG  = -1;
   
   /** Up image to load. */   
   public static final int IMAGE_UP   = 0;
   
   /** Down image to load. */   
   public static final int IMAGE_DOWN = 1;
   
   /** Insensitive image to load. */   
   public static final int IMAGE_INS  = 2;
   
   /** The Progress AUTO-END-KEY attribute. */
   public boolean autoEndKey = false;
  
   /** The Progress AUTO-GO attribute. */
   public boolean autoGo = false;
  
   /** Means whether this button is default one or not. */
   public boolean isDefault = false;

   /** Button image file name. */
   public String image = null;

   /** Button up image file name. */
   public String imageUp = null;

   /** Button down file name. */
   public String imageDown = null;

   /** Button insensitive image file name. */
   public String imageIns = null;

   /** Button NO-FOCUS flag. */
   public boolean noFocus = false;

   /** Button NO-CONVERT-3D-COLORS flag. */
   public boolean noConvert3D = false;
   
   /**
    * Default constructor (only used in deserialization).
    */
   public ButtonConfig()
   {
   }

   /**
    * Create a new config and associate it with the given widget.
    * 
    * @param    id
    *           The ID of the widget to which this configuration belongs.
    */
   protected ButtonConfig(int id)
   {
      super(id);
   }

   /**
    * Create a new config and associate it with the given widget.
    * 
    * @param    id
    *           The ID of the widget to which this configuration belongs.
    */
   protected ButtonConfig(WidgetId id)
   {
      super(id);
   }

   /**
    * Set new values from the provided configuration instance.
    * 
    * @param    config
    *           The instance from which to take values.
    */
   @Override
   public void applyConfig(WidgetConfig config)
   {
      super.applyConfig(config);
      
      ButtonConfig cfg = (ButtonConfig) config;
      
      autoEndKey = cfg.autoEndKey;
      autoGo = cfg.autoGo;
      isDefault = cfg.isDefault;
      image = cfg.image;
      imageUp = cfg.imageUp;
      imageDown = cfg.imageDown;
      imageIns = cfg.imageIns;
      noFocus = cfg.noFocus;
      noConvert3D = cfg.noConvert3D;
   }

   /**
    * Replacement for the default object reading method. The latest
    * state is read from the input source.  The parent's state is
    * read first.
    * 
    * @param    in
    *           The input source from which fields will be restored.
    *
    * @throws   IOException
    *           In case of I/O errors.
    * @throws   ClassNotFoundException
    *           If payload can't be instantiated.
    */
   @Override
   public void readExternal(ObjectInput in)
   throws IOException,
          ClassNotFoundException
   {
      super.readExternal(in);
      autoEndKey = in.readBoolean();
      autoGo     = in.readBoolean();
      isDefault  = in.readBoolean();
      noFocus    = in.readBoolean();
      noConvert3D = in.readBoolean();
      image      = (String) in.readObject();
      imageUp    = (String) in.readObject();
      imageDown  = (String) in.readObject();
      imageIns   = (String) in.readObject();
   }

   /**
    * Replacement for the default object writing method. The latest
    * state is written to the output destination.  The parent's state is
    * written first.
    * 
    * @param    out
    *           The output destination to which fields will be saved.
    *
    * @throws   IOException
    *           In case of I/O errors.
    */
   @Override
   public void writeExternal(ObjectOutput out)
   throws IOException
   {
      super.writeExternal(out);
      out.writeBoolean(autoEndKey);
      out.writeBoolean(autoGo);
      out.writeBoolean(isDefault);
      out.writeBoolean(noFocus);
      out.writeBoolean(noConvert3D);
      out.writeObject(image);
      out.writeObject(imageUp);
      out.writeObject(imageDown);
      out.writeObject(imageIns);
   }
   
   /**
    * Initialize this config.
    */
   protected void init()
   {
      dcolor = Color.NORMAL;
   }
}
